The highest tagged major version is
v2.
package
module
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: Nov 8, 2019
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Loader

Loader is a generic utility to execute function via batching.
The intent is to reduce the number of calls to your function or method.
Getting started
$ go get github.com/rafaelsq/loader
Usage
See loader_test.go
Documentation
¶
type Response struct {
Error error
Value interface{}
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.